@@ -1,4 +1,4 @@
-from sys import stderr, stdout
+import sys
 
 from csv import Sniffer, reader as csv_reader
 from random import randint
@@ -188,7 +188,7 @@ def fq2fa(input_handle, output_handle):
         for record in SeqIO.parse(input_handle, 'fastq'):
             SeqIO.write(record, output_handle, 'fasta')
     except ValueError as error:
-        stderr.write('Error: {}\n'.format(error))
+        sys.stderr.write('Error: {}\n'.format(error))
         emptyRecord = SeqRecord(Seq.Seq(''), '', '', '')
         SeqIO.write(emptyRecord, output_handle, 'fasta')
 
@@ -241,7 +241,7 @@ def get(name, email, output_handle, start=0, stop=0, orientation=0):
         else:
             handle = Entrez.efetch(db='nuccore', rettype='fasta', id=name)
     except HTTPError: # URLError if NCBI is down.
-        stderr.write('Error: could not retrieve {}\n'.format(name))
+        sys.stderr.write('Error: could not retrieve {}\n'.format(name))
         return
 
     output_handle.write(handle.read())
@@ -295,13 +295,13 @@ def maln(input_handle):
 
     data = {x.name: str(x.seq) for x in SeqIO.parse(input_handle, 'fasta')}
     for j in data:
-        stdout.write(j)
-    stdout.write('\n')
+        sys.stdout.write(j)
+    sys.stdout.write('\n')
     for i in data:
-        stdout.write(i)
+        sys.stdout.write(i)
         for j in data:
-            stdout.write(hamming(data[i], data[j]))
-        stdout.write('\n')
+            sys.stdout.write(hamming(data[i], data[j]))
+        sys.stdout.write('\n')
 
     return distances
 
